@@ -16,6 +16,7 @@ import tkinter.messagebox
 import tkinter.ttk as ttk
 import typing as ty
 import webbrowser
+from datetime import datetime
 from logging import getLogger
 from pathlib import Path
 from tempfile import NamedTemporaryFile
@@ -34,8 +35,9 @@ from dvr_scan.config import (
     ConfigLoadFailure,
     ConfigRegistry,
 )
+from dvr_scan.platform import open_path
 from dvr_scan.scanner import OutputMode, Point
-from dvr_scan.shared import ScanSettings
+from dvr_scan.shared import ScanSettings, logfile_path
 from dvr_scan.subtractor import SubtractorCudaMOG2
 from dvr_scan.video_joiner import BackendUnavailable
 
@@ -85,7 +87,7 @@ class InputArea:
 
         self._videos = ttk.Treeview(
             frame,
-            columns=("duration", "framerate", "resolution", "path"),
+            columns=("duration", "framerate", "resolution", "path", "date"),
         )
 
         scroll_horizontal = ttk.Scrollbar(frame, orient=tk.HORIZONTAL, command=self._videos.xview)
@@ -99,16 +101,24 @@ class InputArea:
         self._videos.grid(row=0, column=0, sticky=tk.NSEW)
         frame.grid(row=0, column=0, rowspan=2, columnspan=6, sticky=tk.NSEW)
 
-        self._videos.heading("#0", text="Name")
+        self._videos.heading("#0", text="Name", command=lambda: self._sort_column("#0", False))
         self._videos.column("#0", width=180, minwidth=80, stretch=False)
-        self._videos.heading("duration", text="Duration")
+        self._videos.heading(
+            "duration", text="Duration", command=lambda: self._sort_column("duration", False)
+        )
         self._videos.column("duration", width=80, minwidth=80, stretch=False)
-        self._videos.heading("framerate", text="Framerate")
+        self._videos.heading(
+            "framerate", text="Framerate", command=lambda: self._sort_column("framerate", False)
+        )
         self._videos.column("framerate", width=80, minwidth=80, stretch=False)
-        self._videos.heading("resolution", text="Resolution")
+        self._videos.heading(
+            "resolution", text="Resolution", command=lambda: self._sort_column("resolution", False)
+        )
         self._videos.column("resolution", width=80, minwidth=80, stretch=False)
-        self._videos.heading("path", text="Path")
+        self._videos.heading("path", text="Path", command=lambda: self._sort_column("path", False))
         self._videos.column("path", width=80, minwidth=80, stretch=False)
+        self._videos.heading("date", text="Date", command=lambda: self._sort_column("date", False))
+        self._videos.column("date", width=140, minwidth=80, stretch=False)
 
         self._videos.grid(row=0, column=0, columnspan=6, sticky=tk.NSEW)
 
@@ -212,6 +222,16 @@ class InputArea:
             settings.set("regions", self._region_editor.shapes)
         return settings
 
+    def _sort_column(self, col, reverse):
+        if col == "#0":
+            items = [(self._videos.item(k, "text"), k) for k in self._videos.get_children("")]
+        else:
+            items = [(self._videos.set(k, col), k) for k in self._videos.get_children("")]
+        items.sort(reverse=reverse)
+        for index, (_val, k) in enumerate(items):
+            self._videos.move(k, "", index)
+        self._videos.heading(col, command=lambda: self._sort_column(col, not reverse))
+
     def _add_video(self, path: str = ""):
         paths = []
         if not path:
@@ -231,7 +251,15 @@ class InputArea:
                 logger.error(f"File does not exist: {path}")
                 return
             try:
-                video = open_video(path, backend="opencv")
+                video = open_video(path, backend="opencv")  # logs errors on failure
+                try:
+                    # On Windows, ctime is creation time. On other systems, it may be the
+                    # last metadata change time.
+                    create_time = datetime.fromtimestamp(Path(path).stat().st_ctime)
+                    create_time_str = create_time.strftime("%Y-%m-%d %H:%M:%S")
+                except OSError as ex:
+                    logger.debug(f"Failed to stat {path}: {ex}")
+                    create_time_str = "N/A"
             except VideoOpenFailure:
                 failed_to_load = True
                 continue
@@ -243,7 +271,7 @@ class InputArea:
                 "",
                 tk.END,
                 text=video.name,
-                values=(duration, framerate, resolution, path),
+                values=(duration, framerate, resolution, path, create_time_str),
             )
         if failed_to_load:
             tkinter.messagebox.showwarning(
@@ -639,6 +667,42 @@ class MotionSettingsWindow:
             row=1, column=4, padx=PADDING, sticky=EXPAND_HORIZONTAL, pady=PADDING
         )
 
+        tk.Label(frame, text="Max Area").grid(
+            row=0, column=0, padx=PADDING, sticky=EXPAND_HORIZONTAL, pady=PADDING
+        )
+        self._max_area = Spinbox(
+            frame,
+            value=str(CONFIG_MAP["max-area"]),
+            from_=0.0,
+            to=1.0,
+            increment=0.01,
+        )
+        self._max_area.grid(row=0, column=1, padx=PADDING, sticky=EXPAND_HORIZONTAL, pady=PADDING)
+
+        tk.Label(frame, text="Max Width").grid(
+            row=0, column=0, padx=PADDING, sticky=EXPAND_HORIZONTAL, pady=PADDING
+        )
+        self._max_width = Spinbox(
+            frame,
+            value=str(CONFIG_MAP["max-width"]),
+            from_=0.0,
+            to=1.0,
+            increment=0.01,
+        )
+        self._max_width.grid(row=0, column=1, padx=PADDING, sticky=EXPAND_HORIZONTAL, pady=PADDING)
+
+        tk.Label(frame, text="Max Height").grid(
+            row=0, column=0, padx=PADDING, sticky=EXPAND_HORIZONTAL, pady=PADDING
+        )
+        self._max_height = Spinbox(
+            frame,
+            value=str(CONFIG_MAP["max-height"]),
+            from_=0.0,
+            to=1.0,
+            increment=0.01,
+        )
+        self._max_height.grid(row=0, column=1, padx=PADDING, sticky=EXPAND_HORIZONTAL, pady=PADDING)
+
         tk.Button(self._window, text="Close", command=self._dismiss).grid(
             row=2, column=0, sticky=tk.E, padx=PADDING, pady=PADDING
         )
@@ -708,6 +772,9 @@ class MotionSettingsWindow:
         self._time_before_event.set(settings.get("time-before-event"))
         self._time_post_event.set(settings.get("time-post-event"))
         self._max_threshold.set(settings.get("max-threshold"))
+        self._max_area.set(settings.get("max-area"))
+        self._max_width.set(settings.get("max-width"))
+        self._max_height.set(settings.get("max-height"))
         self._variance_threshold.set(settings.get("variance-threshold"))
 
     def update(self, settings: ScanSettings) -> ScanSettings:
@@ -719,6 +786,9 @@ class MotionSettingsWindow:
         settings.set("time-post-event", self._time_post_event.get())
         settings.set("learning-rate", float(self._learning_rate))
         settings.set("max-threshold", float(self._max_threshold.get()))
+        settings.set("max-area", float(self._max_area.get()))
+        settings.set("max-width", float(self._max_width.get()))
+        settings.set("max-height", float(self._max_height.get()))
         settings.set("variance-threshold", float(self._variance_threshold.get()))
         # NOTE: There is no mask-output in the get function above as it does not exist in the
         # config file (CLI only).
@@ -754,12 +824,22 @@ class OutputArea:
         )
         self._options_button.grid(row=0, column=2, sticky=EXPAND_HORIZONTAL, pady=(0, PADDING))
 
+        self._combine = tk.BooleanVar(root, value=False)
+        self._combine_button = ttk.Checkbutton(
+            root,
+            text="Combine Events",
+            variable=self._combine,
+            onvalue=True,
+            offvalue=False,
+        )
+        self._combine_button.grid(row=0, column=3, sticky=tk.W, padx=PADDING)
+
         self._output_mode_combo["values"] = (
             "OpenCV (.avi)",
             "ffmpeg",
             "ffmpeg (copy)",
         )
-        self._output_mode_combo.current(1)
+        self._output_mode_combo.current(0)
 
         self._output_dir_str = ""
         self._output_dir_label = tk.StringVar(root, value="Ask Me")
@@ -1114,6 +1194,12 @@ class OutputArea:
         self._options_button["state"] = (
             tk.DISABLED if self._output_mode == OutputMode.COPY else tk.NORMAL
         )
+        combine_allowed = self._output_mode is OutputMode.OPENCV
+        self._combine_button["state"] = tk.NORMAL if combine_allowed else tk.DISABLED
+
+    @property
+    def combine(self) -> bool:
+        return self._output_mode == OutputMode.OPENCV and self._combine.get()
 
     @property
     def _output_mode(self) -> OutputMode:
@@ -1127,12 +1213,12 @@ class OutputArea:
 
     @_output_mode.setter
     def _output_mode(self, newval: OutputMode):
-        assert newval != OutputMode.SCAN_ONLY  # Scan only is a separate checkbox in the UI.
-        if newval == OutputMode.OPENCV:
+        assert newval is not OutputMode.SCAN_ONLY  # Scan only is a separate checkbox in the UI.
+        if newval is OutputMode.OPENCV:
             self._output_mode_combo.current(0)
-        elif newval == OutputMode.FFMPEG:
+        elif newval is OutputMode.FFMPEG:
             self._output_mode_combo.current(1)
-        elif newval == OutputMode.COPY:
+        elif newval is OutputMode.COPY:
             self._output_mode_combo.current(2)
 
     @property
@@ -1152,7 +1238,7 @@ class OutputArea:
 
     def load(self, settings: ScanSettings):
         output_mode = OutputMode[settings.get("output-mode").upper()]
-        if output_mode != OutputMode.SCAN_ONLY:
+        if output_mode is not OutputMode.SCAN_ONLY:
             self._output_mode = output_mode
         output_dir = settings.get("output-dir")
         if output_dir:
@@ -1175,6 +1261,7 @@ class OutputArea:
         self._bounding_box_min_size.set(settings.get("bounding-box-min-size"))
         self._bounding_box_smooth_time.set(settings.get("bounding-box-smooth-time"))
         self._bounding_box_thickness.set(settings.get("bounding-box-thickness"))
+        self._on_mode_combo_selected()
 
     def save(self, settings: ScanSettings) -> ScanSettings:
         settings.set("output-mode", self._output_mode)
@@ -1233,15 +1320,27 @@ class ScanArea:
         )
         self._scan_only_button.grid(row=1, column=0, sticky=tk.W)
 
+        self._open_on_completion = tk.BooleanVar(frame, value=True)
+        self._open_on_completion_button = ttk.Checkbutton(
+            frame,
+            text="Open folder on completion",
+            variable=self._open_on_completion,
+            onvalue=True,
+            offvalue=False,
+        )
+        self._open_on_completion_button.grid(row=1, column=1, sticky=tk.W)
+
     def disable(self):
         self._start_button["text"] = "Scanning..."
         self._start_button["state"] = tk.DISABLED
         self._scan_only_button["state"] = tk.DISABLED
+        self._open_on_completion_button["state"] = tk.DISABLED
 
     def enable(self):
         self._start_button["text"] = "Start"
         self._start_button["state"] = tk.NORMAL
         self._scan_only_button["state"] = tk.NORMAL
+        self._open_on_completion_button["state"] = tk.NORMAL
 
     @property
     def scan_only(self) -> bool:
@@ -1251,6 +1350,25 @@ class ScanArea:
     def scan_only(self, newval: bool):
         self._scan_only.set(newval)
 
+    @property
+    def open_on_completion(self) -> bool:
+        return self._open_on_completion.get()
+
+    @open_on_completion.setter
+    def open_on_completion(self, newval: bool):
+        self._open_on_completion.set(newval)
+
+    def save(self, settings: ScanSettings) -> ScanSettings:
+        settings.set("scan-only", self.scan_only)
+        settings.set("open-output-dir", self.open_on_completion)
+        return settings
+
+    def load(self, settings: ScanSettings):
+        output_mode = OutputMode[settings.get("output-mode").upper()]
+        if settings.get("scan-only") or output_mode == OutputMode.SCAN_ONLY:
+            self.scan_only = True
+        self.open_on_completion = settings.get("open-output-dir")
+
 
 class Application:
     def run(self):
@@ -1366,13 +1484,18 @@ class Application:
             underline=0,
         )
         help_menu.add_command(
-            label="Join Discord Chat",
+            label="Open Discord",
             command=lambda: webbrowser.open_new_tab("https://discord.gg/69kf6f2Exb"),
             underline=5,
         )
+        help_menu.add_separator()
+        help_menu.add_command(
+            label="Open Logs",
+            command=lambda: open_path(logfile_path("dvr-scan.log").parent),
+            underline=5,
+        )
         # TODO: Add window to show log messages and copy them to clipboard or save to a logfile.
         # help_menu.add_command(label="Debug Log", underline=0, state=tk.DISABLED)
-        help_menu.add_separator()
 
         help_menu.add_command(
             label="About DVR-Scan",
@@ -1495,8 +1618,7 @@ class Application:
         self._input_settings_window.set(settings)
         self._motion_settings_window.set(settings)
         self._output_area.load(settings)
-        if OutputMode[settings.get("output-mode").upper()] == OutputMode.SCAN_ONLY:
-            self._scan_area.scan_only = True
+        self._scan_area.load(settings)
 
     def _on_save_config(self):
         save_path = tkinter.filedialog.asksaveasfilename(
@@ -1534,6 +1656,7 @@ class Application:
         settings = self._input_settings_window.update(settings)
         settings = self._motion_settings_window.update(settings)
         settings = self._output_area.save(settings)
+        settings = self._scan_area.save(settings)
         return settings
 
     def _get_settings(self) -> ty.Optional[ScanSettings]:
@@ -1545,23 +1668,30 @@ class Application:
         settings = self._input_settings_window.update(settings)
         settings = self._motion_settings_window.update(settings)
         settings = self._output_area.save(settings)
+        settings = self._scan_area.save(settings)
 
-        settings.set("scan-only", self._scan_area.scan_only)
+        output_mode = (
+            OutputMode.SCAN_ONLY if settings.get("scan-only") else settings.get("output-mode")
+        )
+        # Check if we are going to create any output files. We will create files as long as we're
+        # not in scan-only mode, or if we
         if not settings.get("output-dir") and (
-            not settings.get("scan-only") or settings.get("mask-output")
+            output_mode != OutputMode.SCAN_ONLY or settings.get("mask-output")
         ):
             # We will create files but an output directory wasn't set ahead of time - prompt the
             # user to select one.
             output_dir = tkinter.filedialog.askdirectory(
                 title="Set Output Directory", mustexist=True
             )
-            if output_dir:
-                settings.set("output-dir", output_dir)
-            else:
+            if not output_dir:
                 return None
+            settings.set("output-dir", output_dir)
+
+        video_name = Path(settings.get("input")[0]).stem
+        if self._output_area.combine:
+            settings.set("output", f"{video_name}-events.avi")
 
         if settings.get("mask-output"):
-            video_name = Path(settings.get("input")[0]).stem
             settings.set("mask-output", f"{video_name}-mask.avi")
 
         if not self._input_area.concatenate and len(settings.get_arg("input")) > 1:
